AS7262 Spectral Sensor
======================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

Suitable for detecting the properties of ambient light, light passing
through a liquid or light reflected from an object the AS7262 spectral
sensor has 6 spectral channels at 450 (violet), 500 (blue), 550 (green),
570 (yellow), 600 (orange) and 650nm (red).

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install as7262``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/as7262-python``
-  ``cd as7262-python``
-  ``sudo ./install.sh``

.. |Build Status| image:: https://travis-ci.com/pimoroni/as7262-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/as7262-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/as7262-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/as7262-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/as7262.svg
   :target: https://pypi.python.org/pypi/as7262
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/as7262.svg
   :target: https://pypi.python.org/pypi/as7262
